==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/zh_TW.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "activated" : "已啟用",
    "updated" : "已更新",
    "mounted" : "已掛載",
    "deactivated" : "已停用",
    "beforeCreate" : "建立前",
    "created" : "已建立",
    "beforeUpdate" : "更新前",
    "beforeDestroy" : "銷毀前",
    "destroyed" : "已銷毀",
    "beforeMount" : "掛載前",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "以下是您的備用碼，由於備用碼不會再次顯示，請儲存 並/或 列印。",
    "Save backup codes" : "儲存備用碼",
    "Print backup codes" : "列印備用碼",
    "Backup codes have been generated. {used} of {total} codes have been used." : "備用碼已經建立，共{total}組備用碼中有{userd}組已經使用",
    "Regenerate backup codes" : "重新產生備用碼",
    "_icon-loading-small_::_generate-backup-codes_" : ["產生備用碼"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "若您重新產生備用碼，原來舊的備用碼將自動失效。",
    "Generate backup codes" : "產生備用碼",
    "An error occurred while generating your backup codes" : "產生備用碼時發生錯誤。",
    "Nextcloud backup codes" : "Nextcloud 備用碼",
    "You created two-factor backup codes for your account" : "你的帳戶已建立兩階段認證的備用碼。",
    "Second-factor backup codes" : "第二階段認證備用碼",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "您已經啟用兩階段驗證功能，但您未產生備用碼，請進行此步驟以免失去兩階段驗證功能失效時無法存取。",
    "Backup code" : "備用碼",
    "Use backup code" : "使用備用碼",
    "Two factor backup codes" : "兩階段驗證備用碼",
    "A two-factor auth backup codes provider" : "兩階段驗證備用碼供應商",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "設定啟用兩階段驗證時，可輸入其中一個您已儲存的備用碼。",
    "Submit" : "送出",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "備用碼已經建立。{{total}}組中有{{used}}組備用碼已被使用過"
},
"nplurals=1; plural=0;");

==> nextcloud-15.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/zh_TW.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "An error occurred while generating your backup codes" : "產生備用碼時發生錯誤。",
    "Nextcloud backup codes" : "Nextcloud 備用碼",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "以下是您的備用碼，由於備用碼不會再次顯示，請儲存 並/或 列印。",
    "Save backup codes" : "儲存備用碼",
    "Print backup codes" : "列印備用碼",
    "Backup codes have been generated. {used} of {total} codes have been used." : "備用碼已經建立，共{total}組備用碼中有{used}組已經使用",
    "Regenerate backup codes" : "重新產生備用碼",
    "_icon-loading-small_::_generate-backup-codes_" : ["產生備用碼"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "若您重新產生備用碼，原來舊的備用碼將自動失效。",
    "Generate backup codes" : "產生備用碼",
    "You created two-factor backup codes for your account" : "你的帳戶已建立兩階段認證的備用碼。",
    "Second-factor backup codes" : "第二階段認證備用碼",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "您已經啟用兩階段驗證功能，但您未產生備用碼，請進行此步驟以免失去兩階段驗證功能失效時無法存取。",
    "Backup code" : "備用碼",
    "Use backup code" : "使用備用碼",
    "Two factor backup codes" : "兩階段驗證備用碼",
    "A two-factor auth backup codes provider" : "兩階段驗證備用碼供應商",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "設定啟用兩階段驗證時，可輸入其中一個您已儲存的備用碼。",
    "Submit" : "送出",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "備用碼已經建立。{{total}}組中有{{used}}組備用碼已被使用過",
    "activated" : "已啟用",
    "updated" : "已更新",
    "mounted" : "已掛載",
    "deactivated" : "已停用",
    "beforeCreate" : "建立前",
    "created" : "已建立",
    "beforeUpdate" : "更新前",
    "beforeDestroy" : "銷毀前",
    "destroyed" : "已銷毀",
    "beforeMount" : "掛載前"
},
"nplurals=1; plural=0;");
